pub struct AddressMetrics {
pub responded: usize,
pub never_attempted_gossiped: usize,
pub failed: usize,
pub attempt_pending: usize,
pub recently_live: usize,
pub recently_stopped_responding: usize,
pub num_addresses: usize,
pub address_limit: usize,
}Expand description
Metrics about the states of the addresses in an AddressBook.
Fields
responded: usizeThe number of addresses in the Responded state.
never_attempted_gossiped: usizeThe number of addresses in the NeverAttemptedGossiped state.
failed: usizeThe number of addresses in the Failed state.
attempt_pending: usizeThe number of addresses in the AttemptPending state.
recently_live: usizeThe number of Responded addresses within the liveness limit.
recently_stopped_responding: usizeThe number of Responded addresses outside the liveness limit.
num_addresses: usizeThe number of addresses in the address book, regardless of their states.
address_limit: usizeThe maximum number of addresses in the address book.